@@ -31,6 +31,7 @@ __all__ = (
     "BuildStatusConfigTypeDef",
     "BuildTypeDef",
     "CloudWatchLogsConfigTypeDef",
+    "DebugSessionTypeDef",
     "EnvironmentImageTypeDef",
     "EnvironmentLanguageTypeDef",
     "EnvironmentPlatformTypeDef",
@@ -179,6 +180,7 @@ BuildTypeDef = TypedDict(
         "exportedEnvironmentVariables": List["ExportedEnvironmentVariableTypeDef"],
         "reportArns": List[str],
         "fileSystemLocations": List["ProjectFileSystemLocationTypeDef"],
+        "debugSession": "DebugSessionTypeDef",
     },
     total=False,
 )
@@ -197,6 +199,10 @@ class CloudWatchLogsConfigTypeDef(
     pass
 
 
+DebugSessionTypeDef = TypedDict(
+    "DebugSessionTypeDef", {"sessionEnabled": bool, "sessionTarget": str}, total=False
+)
+
 EnvironmentImageTypeDef = TypedDict(
     "EnvironmentImageTypeDef", {"name": str, "description": str, "versions": List[str]}, total=False
 )
@@ -331,7 +337,11 @@ _RequiredProjectEnvironmentTypeDef = TypedDict(
     "_RequiredProjectEnvironmentTypeDef",
     {
         "type": Literal[
-            "WINDOWS_CONTAINER", "LINUX_CONTAINER", "LINUX_GPU_CONTAINER", "ARM_CONTAINER"
+            "WINDOWS_CONTAINER",
+            "LINUX_CONTAINER",
+            "LINUX_GPU_CONTAINER",
+            "ARM_CONTAINER",
+            "WINDOWS_SERVER_2019_CONTAINER",
         ],
         "image": str,
         "computeType": Literal[
